@@ -25,8 +25,10 @@
 
 BufferMIDIInterface::BufferMIDIInterface(BufferMIDI *midi, DirectionFlags flags, QObject *parent) :
     MIDIInterface(flags, parent),
-    midi(midi)
+    midi(midi),
+    oldTick(0)
 {
+    setEnabled(true);
 }
 
 void BufferMIDIInterface::tempo(unsigned int tempo)
@@ -91,6 +93,36 @@ void BufferMIDIInterface::write(const QByteArray &dataArray)
         write(QByteArray(newmessage, length + l));
         delete [] newmessage;
     } else {
+        unsigned int delta = tick - oldTick;
+        oldTick = tick;
+        unsigned long value = delta;
+        unsigned long varlen = value & 0x7F;
+
+        // Create a variable length version of the tick delta
+        while ((value >>= 7)) {
+            varlen <<= 8;
+            varlen |= ((value & 0x7F) | 0x80);
+        }
+
+        // Check how many bytes the varlen version requires
+        value = varlen;
+        for (int i = 1; i <= 4; i++) {
+            if (value & 0x80)
+                value >>= 8;
+            else
+                break;
+        }
+
+        // Write the varlen tick delta value
+        for (int i = 1; i <= 4; i++) {
+            data_.append((unsigned char)(varlen & 0xff));
+            if (varlen & 0x80)
+                varlen >>= 8;
+            else
+                break;
+        }
+
+        // Write the actual payload */
         data_.append(data, length);
     }
 }
