@@ -1,6 +1,6 @@
 /* conversion.cpp
  *
- * Copyright 2002-2016 Vesa Halttunen
+ * Copyright 2002-2017 Vesa Halttunen
  *
  * This file is part of Tutka.
  *
@@ -179,7 +179,7 @@ Song *mmd2ToSong(struct MMD2 *mmd)
     if (mmd->expdata != NULL && mmd->expdata->songname != NULL) {
         song->setName(QString::fromLatin1(mmd->expdata->songname));
     } else {
-        song->setName("Untitled");
+        song->setName(QObject::tr("Untitled"));
     }
 
     if (mmd->song) {
@@ -254,7 +254,6 @@ Song *mmd2ToSong(struct MMD2 *mmd)
 
         // Playing sequences
         for (int playseq = song->playseqs(); playseq < mmd->song->numpseqs; playseq++) {
-            qWarning("XX inserting playseq %d", playseq);
             song->insertPlayseq(playseq);
         }
         for (int number = 0; number < mmd->song->numpseqs; number++) {
