@@ -1,7 +1,7 @@
 /*
  * instrumentspinbox.cpp
  *
- * Copyright 2002-2016 Vesa Halttunen
+ * Copyright 2002-2017 Vesa Halttunen
  *
  * This file is part of Tutka.
  *
@@ -29,10 +29,10 @@ InstrumentSpinBox::InstrumentSpinBox(QWidget *parent) :
 
 QString InstrumentSpinBox::textFromValue(int value) const
 {
-    return QString("%1").arg(value + 1, 2, 16, QChar('0')).toUpper();
+    return QString("%1").arg(value, 2, 16, QChar('0')).toUpper();
 }
 
 int InstrumentSpinBox::valueFromText(const QString &text) const
 {
-    return text.toInt(NULL, 16) - 1;
+    return text.toInt(NULL, 16);
 }
