@@ -730,7 +730,7 @@ void MainWindow::setSelection(int startTrack, int startLine, int endTrack, int e
 
 void MainWindow::showAbout()
 {
-    QMessageBox::about(this, tr("About Tutka"), tr("Tutka 1.1.1\n\n© 2002-2017 Vesa Halttunen <vesuri@jormas.com>"));
+    QMessageBox::about(this, tr("About Tutka"), tr("Tutka 1.1.2\n\n© 2002-2017 Vesa Halttunen <vesuri@jormas.com>"));
 }
 
 void MainWindow::cutSelection()
@@ -882,6 +882,9 @@ void MainWindow::saveAs()
             smf->save(path);
             delete smf;
         } else {
+            if (!path.endsWith(".tutka")) {
+                path.append(".tutka");
+            }
             song->save(path);
         }
 
