@@ -1,7 +1,7 @@
 /*
  * trackvolumewidget.h
  *
- * Copyright 2002-2016 Vesa Halttunen
+ * Copyright 2002-2017 Vesa Halttunen
  *
  * This file is part of Tutka.
  *
@@ -35,7 +35,9 @@ class TrackVolumeWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit TrackVolumeWidget(unsigned int number, Track *track, QWidget *parent = 0);
+    explicit TrackVolumeWidget(unsigned int number, Track *track = NULL, QWidget *parent = 0);
+
+    void setTrack(Track *track);
 
 private slots:
     void updateVolumeLabel(int volume);
